@@ -24,9 +24,7 @@ dt <- function(.df, ...) {
 }
 
 #' @export
-dt.data.frame <- function(.df, ...) {
-  .df <- as_tidytable(.df)
-
+dt.tidytable <- function(.df, ...) {
   dots <- substitute(list(...))
 
   needs_copy <- str_detect.(expr_text(dots), ":=")
@@ -35,3 +33,9 @@ dt.data.frame <- function(.df, ...) {
 
   .df[...]
 }
+
+#' @export
+dt.data.frame <- function(.df, ...) {
+  .df <- as_tidytable(.df)
+  dt(.df, ...)
+}
