@@ -4,10 +4,10 @@
 #' @import vctrs
 #' @rawNamespace import(rlang, except = `:=`)
 #' @importFrom glue glue glue_data
-#' @importFrom lifecycle deprecated deprecate_soft deprecate_stop
+#' @importFrom lifecycle deprecate_warn deprecate_stop
 #' @importFrom pillar glimpse dim_desc tbl_sum
 #' @importFrom stats na.omit
-#' @importFrom utils head packageName tail type.convert
+#' @importFrom utils head tail type.convert
 NULL
 
 #' @docType import
@@ -58,6 +58,9 @@ data.table::getDTthreads
 #' @export
 data.table::setDTthreads
 
+#' @export
+data.table::`%chin%`
+
 # rlang ------------------------
 #' @export
 rlang::enquo
