@@ -1,15 +1,16 @@
-#' Unnest a nested data.table
+#' Unnest list-columns
 #'
 #' @description
-#' Unnest a nested data.table.
+#' Unnest list-columns.
 #'
-#' @param .df A nested data.table
+#' @param .df A data.table
 #' @param ... Columns to unnest. If empty, unnests all list columns. `tidyselect` compatible.
+#' @param keep_empty Return `NA` for any `NULL` elements of the list column
 #' @param .drop Should list columns that were not unnested be dropped
 #' @param names_sep If NULL, the default, the inner column names will become the new outer column names.
 #'
-#' If a string, the name of the outer column will be appended to the beginning of the inner column names,
-#' with `names_sep` used as a separator.
+#'   If a string, the name of the outer column will be appended to the beginning of the inner column names,
+#'   with `names_sep` used as a separator.
 #'
 #' @param names_repair Treatment of duplicate names. See `?vctrs::vec_as_names` for options/details.
 #'
@@ -36,6 +37,7 @@
 #'   unnest.(data, pulled_vec)
 unnest. <- function(.df,
                     ...,
+                    keep_empty = FALSE,
                     .drop = TRUE,
                     names_sep = NULL,
                     names_repair = "unique") {
@@ -45,6 +47,7 @@ unnest. <- function(.df,
 #' @export
 unnest..tidytable <- function(.df,
                               ...,
+                              keep_empty = FALSE,
                               .drop = TRUE,
                               names_sep = NULL,
                               names_repair = "unique") {
@@ -62,12 +65,14 @@ unnest..tidytable <- function(.df,
     dots <- tidyselect_syms(.df, ...)
   }
 
-  keep_cols <- data_names[!list_bool]
+  if (.drop) {
+    keep_cols <- data_names[!list_bool]
+  } else {
+    keep_cols <- data_names[data_names %notin% as.character(dots)]
+  }
 
-  if (!.drop) {
-    list_cols <- data_names[list_bool]
-
-    keep_cols <- c(keep_cols, list_cols[list_cols %notin% as.character(dots)])
+  if (keep_empty) {
+    .df <- mutate_lapply(.df, as.character(dots), keep_empty_prep)
   }
 
   unnest_data <- map.(dots, ~ unnest_col(.df, .x, names_sep))
@@ -81,9 +86,9 @@ unnest..tidytable <- function(.df,
   # Get number of repeats for keep cols
   rep_vec <- list_sizes(pull.(.df, !!dots[[1]]))
 
-  keep_df <- .df[, ..keep_cols]
+  if (length(keep_cols) > 0) {
+    keep_df <- .df[, ..keep_cols]
 
-  if (ncol(keep_df) > 0) {
     keep_df <- keep_df[vec_rep_each(1:.N, rep_vec)]
 
     result_df <- bind_cols.(keep_df, unnest_data, .name_repair = names_repair)
@@ -97,23 +102,30 @@ unnest..tidytable <- function(.df,
 #' @export
 unnest..data.frame <- function(.df,
                                ...,
+                               keep_empty = FALSE,
                                .drop = TRUE,
                                names_sep = NULL,
                                names_repair = "unique") {
   .df <- as_tidytable(.df)
-  unnest.(.df, ..., .drop = .drop, names_sep = names_sep, names_repair = names_repair)
+  unnest.(
+    .df, ..., keep_empty = keep_empty, .drop = .drop,
+    names_sep = names_sep, names_repair = names_repair
+  )
 }
 
 unnest_col <- function(.df, col = NULL, names_sep = NULL) {
-  # Check if nested data is a vector
-  nested_data <- pull.(.df, !!col)[[1]]
-  is_vec <- is.atomic(nested_data) && !is.matrix(nested_data)
+  .l <- pull.(.df, !!col)
+
+  null_bool <- map_lgl.(.l, is.null)
+
+  .check_data <- .l[!null_bool][[1]]
+  is_vec <- is.atomic(.check_data) && !is.matrix(.check_data)
 
   if (is_vec) {
-    result_df <- summarize.(.df, !!col := unlist(!!col, recursive = FALSE))
+    # Use do.call so lists of dates are not unclassed by unlist
+    result_df <- tidytable(!!col := do.call("c", .l))
   } else {
-    # bind_rows.() auto-converts lists of data.frames/tibbles/matrices to data.tables
-    result_df <- bind_rows.(pull.(.df, !!col))
+    result_df <- bind_rows.(.l)
   }
 
   if (!is.null(names_sep)) {
@@ -123,4 +135,24 @@ unnest_col <- function(.df, col = NULL, names_sep = NULL) {
   result_df
 }
 
+keep_empty_prep <- function(.l) {
+  null_bool <- map_lgl.(.l, is.null)
+
+  if (!any(null_bool)) return(.l)
+
+  .check_data <- .l[!null_bool][[1]]
+  is_vec <- is.atomic(.check_data) && !is.matrix(.check_data)
+
+  if (is_vec) {
+    .replace <- NA
+  } else {
+    null_df <- vec_slice(.check_data, 1)
+    vec_slice(null_df, 1) <- NA
+
+    .replace <- list(null_df)
+  }
+
+  replace_na.(.l, .replace)
+}
+
 globalVariables("..keep_cols")
