@@ -4,12 +4,12 @@ shallow <- function(x) {
   x[TRUE]
 }
 
-# Create a call to data.table subset "[" (i position)
+# Create a call to "[.data.table" (i position)
 call2_i <- function(data, i = NULL) {
   call2("[", data, i)
 }
 
-# Create a call to data.table subset "[" (j position)
+# Create a call to "[.data.table" (j position)
 call2_j <- function(data, j = NULL, .by = NULL, ...) {
   dt_expr <- call2("[", data, , j, by = .by, ...)
   call2("[", dt_expr)
@@ -98,6 +98,7 @@ args_recycle <- function(args) {
   args
 }
 
+# Restore user defined attributes
 tidytable_restore <- function(x, to) {
   # Make sure auto-index is reset since vec_restore reapplies the original index
   # https://github.com/Rdatatable/data.table/issues/5042
@@ -105,6 +106,53 @@ tidytable_restore <- function(x, to) {
   vec_restore(x, to)
 }
 
+deprecate_old_across <- function(fn) {
+  .what <- glue("tidytable::{fn}_across.()")
+  .details <- glue("Please use `{fn}.(across.())")
+
+  deprecate_warn("0.6.4", what = .what, details = .details, id = fn)
+}
+
+# Does type changes with either ptype or transform logic
+# For use in pivot_longer/unnest_longer/unnest_wider
+change_types <- function(.df, .to, .list, .ptypes_transform) {
+  vars <- intersect(.to, names(.list))
+  if (length(vars) > 0) {
+    calls <- vector("list", length(vars))
+    names(calls) <- vars
+    if (.ptypes_transform == "ptypes") {
+      .fn <- "vec_cast"
+      for (i in seq_along(vars)) {
+        calls[[i]] <- call2(.fn, sym(vars[[i]]), .list[[i]])
+      }
+    } else if (.ptypes_transform == "transform") {
+      for (i in seq_along(vars)) {
+        .fn <- as_function(.list[[i]])
+        calls[[i]] <- call2(.fn, sym(vars[[i]]))
+      }
+    } else {
+      abort("Please specify ptypes or transform")
+    }
+    .df <- mutate.(.df, !!!calls)
+  }
+  .df
+}
+
+# Internal mutate.(across.())
+# Use when you don't want to repeat tidyselect steps
+# .cols and .by should be character vectors
+mutate_lapply <- function(.df, .cols, fn, ..., .by = character()) {
+  if (length(.by) == 0) {
+    .df <- shallow(.df)
+  } else {
+    copy(.df)
+  }
+
+  .df[, (.cols) := map.(.SD, fn, ...), by = .by, .SDcols = .cols]
+
+  .df
+}
+
 # deprecated shallow() ------------------------------------------------
 # shallow <- function(x, cols = names(x), reset_class = FALSE) {
 #   stopifnot(is.data.table(x), all(cols %in% names(x)))
